[![Contributors][contributors-shield]][contributors-url]
[![Forks][forks-shield]][forks-url]
[![Stargazers][stars-shield]][stars-url]
[![Issues][issues-shield]][issues-url]
[![MIT License][license-shield]][license-url]
[![LinkedIn][linkedin-shield]][linkedin-url]



<!-- PROJECT LOGO -->
<br />
<p align="center">
  <a href="https://github.com/dillir07/aadoc">
    <img src="https://dev-to-uploads.s3.amazonaws.com/i/3evjyabnoghtiojrchcy.PNG" alt="AADoc Logo" width="240" height="80">
  </a>

  <h3 align="center">AADOC</h3>

  <p align="center">
    A tool to generate Documentation from AA Comments
    <br />
    <a href="https://github.com/dillir07/aadoc"><strong>Explore the docs »</strong></a>
    <br />
    <br />
    <a href="https://github.com/dillir07/aadoc">View Demo</a>
    ·
    <a href="https://github.com/dillir07/aadoc/issues">Report Bug</a>
    ·
    <a href="https://github.com/dillir07/aadoc/issues">Request Feature</a>
  </p>
</p>


<!-- TABLE OF CONTENTS -->
## Table of Contents

- [Table of Contents](#table-of-contents)
- [About The Project](#about-the-project)
  - [Built With](#built-with)
- [Getting Started](#getting-started)
  - [Prerequisites](#prerequisites)
- [Usage](#usage)
  - [aadoc "input_folder_path_in_quotes" "optional output path"](#aadoc-%22inputfolderpathinquotes%22-%22optional-output-path%22)
- [Roadmap](#roadmap)
- [Contributing](#contributing)
- [License](#license)
- [Contact](#contact)



<!-- ABOUT THE PROJECT -->
## About The Project

<!-- [![Product Name Screen Shot][product-screenshot]](https://example.com) -->

AADoc is a tool created for generating Doumentation from Automation Anywhere Code's comments. 

### Built With

* Python

<!-- GETTING STARTED -->
## Getting Started

To get a local copy up and running follow these simple steps.

### Prerequisites

This is an example of how to list things you need to use the software and how to install them.

* python
* pip

<!-- ```sh
pip install npm@latest -g
``` -->

### Installation

1. Install AADoc using pip
```sh
pip install aadoc
```



<!-- USAGE EXAMPLES -->
## Usage

<!-- Use this space to show useful examples of how a project can be used. Additional screenshots, code examples and demos work well in this space. You may also link to more resources.

_For more examples, please refer to the [Documentation](https://example.com)_ -->

### aadoc "input_folder_path_in_quotes" "optional output path"



<!-- ROADMAP -->
## Roadmap

See the [open issues](https://github.com/dillir07/aadoc/issues) for a list of proposed features (and known issues).



<!-- CONTRIBUTING -->
## Contributing

<!-- Contributions are what make the open source community such an amazing place to be learn, inspire, and create. Any contributions you make are **greatly appreciated**.

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request -->



<!-- LICENSE -->
## License

Distributed under the GPLv3 License. See `LICENSE` for more information.



<!-- CONTACT -->
## Contact

Dilli Babu R - [@dillir07](https://twitter.com/dillir07) - dillir07@outlook.com

Project Link: [https://github.com/dillir07/aadoc](https://github.com/dillir07/aadoc)



<!-- ACKNOWLEDGEMENTS -->
<!-- ## Acknowledgements

* []()
* []()
* []() -->





<!-- MARKDOWN LINKS & IMAGES -->
<!-- https://www.markdownguide.org/basic-syntax/#reference-style-links -->
[contributors-shield]: https://img.shields.io/github/contributors/dillir07/aadoc?style=flat-square

[contributors-url]: https://github.com/dillir07/Best-README-Template/graphs/contributors

[forks-shield]: https://img.shields.io/github/forks/dillir07/aadoc?style=flat-square

[forks-url]: https://github.com/dillir07/Best-README-Template/network/members

[stars-shield]: https://img.shields.io/github/stars/dillir07/aadoc?style=flat-square

[stars-url]: https://github.com/dillir07/Best-README-Template/stargazers

[issues-shield]: https://img.shields.io/github/issues/dillir07/aadoc?style=flat-square

[issues-url]: https://github.com/dillir07/Best-README-Template/issues

[license-shield]: https://img.shields.io/github/license/dillir07/aadoc?style=flat-square

[license-url]: https://github.com/dillir07/aadoc/blob/master/LICENSE

[linkedin-shield]: https://img.shields.io/badge/-LinkedIn-black.svg?style=flat-square&logo=linkedin&colorB=555

[linkedin-url]: https://linkedin.com/in/dillir07
[product-screenshot]: images/screenshot.png